@@ -148,7 +148,7 @@ class LineVisual(CompoundVisual):
             self._changed[k] = True
 
     def set_data(self, pos=None, color=None, width=None, connect=None):
-        """ Set the data used to draw this visual.
+        """Set the data used to draw this visual.
 
         Parameters
         ----------
@@ -162,13 +162,15 @@ class LineVisual(CompoundVisual):
             to 1 px when using the 'gl' method.
         connect : str or array
             Determines which vertices are connected by lines.
-            * "strip" causes the line to be drawn with each vertex
-              connected to the next.
-            * "segments" causes each pair of vertices to draw an
-              independent line segment
-            * int numpy arrays specify the exact set of segment pairs to
-              connect.
-            * bool numpy arrays specify which _adjacent_ pairs to connect.
+
+                * "strip" causes the line to be drawn with each vertex
+                  connected to the next.
+                * "segments" causes each pair of vertices to draw an
+                  independent line segment
+                * int numpy arrays specify the exact set of segment pairs to
+                  connect.
+                * bool numpy arrays specify which _adjacent_ pairs to connect.
+
         """
         if pos is not None:
             self._bounds = None
@@ -222,17 +224,18 @@ class LineVisual(CompoundVisual):
         else:
             return self._connect
 
-    def _interpret_color(self):
-        if isinstance(self._color, string_types):
+    def _interpret_color(self, color_in=None):
+        color_in = self._color if color_in is None else color_in
+        if isinstance(color_in, string_types):
             try:
-                colormap = get_colormap(self._color)
+                colormap = get_colormap(color_in)
                 color = Function(colormap.glsl_map)
             except KeyError:
-                color = Color(self._color).rgba
-        elif isinstance(self._color, Function):
-            color = Function(self._color)
+                color = Color(color_in).rgba
+        elif isinstance(color_in, Function):
+            color = Function(color_in)
         else:
-            color = ColorArray(self._color).rgba
+            color = ColorArray(color_in).rgba
             if len(color) == 1:
                 color = color[0]
         return color
